namecheap
    * ``auth_token`` Specify api token for authentication

    * ``auth_username`` Specify username for authentication

    * ``auth_client_ip`` Client ip address to send to namecheap api calls

    * ``auth_sandbox`` Whether to use the sandbox server
